Stable integration surface for consumers that embed this crate as a submodule, path dependency, git dependency, or SDK-style library.
Re-exports
pub use crate::client::IndodaxClient;pub use crate::config::IndodaxConfig;pub use crate::config::ResolvedCredentials;pub use crate::config::SecretValue;pub use crate::errors::IndodaxError;