Crate indodax_cli

Crate indodax_cli 

Re-exports

pub use integration::prelude;

Modules

alerts
auth
client
commands
config
errors
integration
Stable integration surface for consumers that embed this crate as a submodule, path dependency, git dependency, or SDK-style library.
mcp
output

Structs

Cli

Enums

Command
WithdrawalSubcommand

Functions

dispatch
map_anyhow_error